@@ -14,12 +14,12 @@ class Api(object):
         Especially useful for navigation, HATEOAS and for providing multiple
         versions of your API.
     """
-    def __init__(self, version, show_map=True, **kwargs):
+    def __init__(self, version=None, show_map=True, **kwargs):
         self.version = version
         self.show_map = show_map
         self.kwargs = kwargs
         try:
-            self.str_version = '.'.join(map(str, version))
+            self.str_version = '.'.join(map(str, version or list()))
         except TypeError:
             self.str_version = str(version)
 
@@ -42,10 +42,16 @@ class Api(object):
             ``Resources`` beneath it.
         """
         patterns = []
+        url_vprefix = name_vprefix = ''
+
+        if self.str_version:
+            url_vprefix = '%s/' % self.str_version
+            name_vprefix = '%s-' % self.str_version
+
         if self.show_map:
             patterns.append(
                 # self top level map
-                url(r"^%s/?$" % self.str_version, ApiMapResource.as_view(api=self), name="api-%s-%s" % ( self.str_version, ApiMapResource.meta.urlname )),
+                url(r"^%s$" % url_vprefix, ApiMapResource.as_view(api=self), name="api-%s%s" % (name_vprefix, ApiMapResource.meta.urlname)),
             )
 
         for urlname in sorted(self._map.keys()):
@@ -61,8 +67,8 @@ class Api(object):
             params.update(resource_info['kwargs'])
 
             # URL
-            urlname = 'api-%s-%s' % ( self.str_version, urlname)
-            urlregex = '^%s/%s' % ( self.str_version, resource_info['urlregex'])
+            urlname = 'api-%s%s' % ( name_vprefix, urlname)
+            urlregex = '^%s%s' % ( url_vprefix, resource_info['urlregex'])
             view = resource.as_view(api=self, **params)
             patterns.append(url(urlregex, view, name=urlname))
 
